@@ -2,3 +2,7 @@
   packageStartupMessage(paste("norgeo version",
                               utils::packageDescription("norgeo")[["Version"]]))
 }
+
+
+# Columnames to be deleted if options for names = FALSE
+granularityNames <- c("oldName", "newName")
